@@ -10,10 +10,7 @@ import publication
 from jsii.python import classproperty
 
 import aws_cdk.aws_iam
-import aws_cdk.aws_kms
 import aws_cdk.aws_lambda
-import aws_cdk.aws_s3
-import aws_cdk.aws_sns
 import aws_cdk.core
 __all__ = []
 
